Subspaces
===================

.. contents::
    :depth: 2
    :local:


.. currentmodule:: cr.nimble.subspaces

Projection
------------------

.. autosummary::
    :toctree: _autosummary

    project_to_subspace
    is_in_subspace


Principal Angles
---------------------------


.. autosummary::
    :toctree: _autosummary

    principal_angles_cos
    principal_angles_rad
    principal_angles_deg
    smallest_principal_angle_cos
    smallest_principal_angle_rad
    smallest_principal_angle_deg
    smallest_principal_angles_cos
    smallest_principal_angles_rad
    smallest_principal_angles_deg
    subspace_distance

